variable "destination_bucket_arn" {
  description = "ARN of the s3 bucket to put data into"
  type        = string
}

variable "source_kinesis_arn" {
  description = "ARN of the kinesis stream to get data from"
  type        = string
  default     = ""
}

variable "iam_role_arn" {
  description = "ARN of the firehose IAM role"
  type        = string
}

variable "kinesis_firehose_name" {
  type        = string
  description = "The name for the stream."
}

variable "stream_prefix" {
  type        = string
  description = "Prefix for s3 directory where data is delivered."
}

variable "error_output_prefix" {
  type        = string
  description = "Prefix added to failed records before writing them to S3."
  default     = ""
}

variable "tags" {
  type        = map(string)
  description = "[Required] The URL to the Gitlab repository where the code resides"
  default     = {}
}

variable "buffer_size" {
  type        = number
  description = "Buffer incoming data to the specified size, in MBs, before delivering it to the destination."
  default     = 5
}

variable "buffer_interval" {
  type        = number
  description = "Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination."
  default     = 300
}

variable "compression_format" {
  type        = string
  description = "The compression format. If no value is specified, the default is UNCOMPRESSED. Other supported values are GZIP, ZIP & Snappy."
  default     = "UNCOMPRESSED"
}

variable "subnet_ids" {
  default     = []
  description = "Declaring unused variable: Using a variables file to set an undeclared variable is deprecated and will become an error in a future release"
  type        = list(string)
}

variable "security_group_ids" {
  default     = []
  description = "Declaring unused variable: Using a variables file to set an undeclared variable is deprecated and will become an error in a future release"
  type        = list(string)
}

variable "iam_policy_prefix" {
  type = string
}

variable "cloudwatch_logging_enabled" {
  type        = bool
  description = "Enables or disables the CloudWatch logging"
  default     = false
}

variable "cloudwatch_logging_log_group_name" {
  type        = string
  description = "The CloudWatch group name for logging. This value is required if CloudWatch logging is enabled."
  default     = null
}

variable "cloudwatch_logging_log_stream_name" {
  type        = string
  description = "The CloudWatch log stream name for logging. This value is required if CloudWatch logging is enabled."
  default     = null
}

variable "dynamic_partitioning_enabled" {
  type        = bool
  description = "Enables or disables the dynamic partitioning"
  default     = false
}

variable "dynamic_partitioning_retry_duration" {
  type        = number
  description = "Total amount of seconds Firehose spends on retries. Valid values between 0 and 7200. Default is 300."
  default     = 300
}

variable "metadata_extraction_enabled" {
  type        = bool
  description = "Enables or disables data processing"
  default     = false
}

variable "metadata_extraction_query" {
  type        = string
  description = "Metadata extraction query. Ex. {customer_id:.customer_id}"
  default     = ""
}

variable "lambda_processor_enabled" {
  type        = bool
  description = "Enables or disables lambda processor"
  default     = false
}

variable "lambda_processor_arn" {
  description = "ARN of the lambda function for dynamic partitioning"
  type        = string
  default     = ""
}

variable "lambda_version" {
  description = "lambda function version for lambda processor"
  type        = string
  default     = "$LATEST"
}

variable "data_format_conversion_enabled" {
  type        = bool
  description = "Enables or disables data format conversion"
  default     = false
}

variable "deserializer" {
  type        = string
  description = "Specifies which deserializer to use. You can choose either hive_json_ser_de or open_x_json_ser_de. Ex. open_x_json_ser_de. "
  default     = "open_x_json_ser_de"
  validation {
    condition     = var.deserializer == "hive_json_ser_de" || var.deserializer == "open_x_json_ser_de"
    error_message = "Data format deserialiser must be a valid option. Valid options - open_x_json_ser_de, hive_json_ser_de."
  }
}

variable "serializer" {
  type        = string
  description = "Specifies which serializer to use. You can choose either orc_ser_de or parquet_ser_de. Ex. parquet_ser_de. "
  default     = "orc_ser_de"
  validation {
    condition     = var.serializer == "parquet_ser_de" || var.serializer == "orc_ser_de"
    error_message = "Data format serializer must be a valid option. Valid options - parquet_ser_de, orc_ser_de."
  }
}

variable "schema_configuration_database_name" {
  type        = string
  description = "Specifies the name of the AWS Glue database that contains the schema for the output data."
  default     = null
}

variable "schema_configuration_table_name" {
  type        = string
  description = "Specifies the name of the AWS Glue table that contains the schema for the output data."
  default     = null
}

variable "schema_configuration_role_arn" {
  type        = string
  description = "The role that Kinesis Data Firehose can use to access AWS Glue. This role must be in the same account you use for Kinesis Data Firehose."
  default     = null
}

variable "enable_iam_policies" {
  type    = bool
  default = true
}